@@ -274,7 +274,7 @@ typedef unsigned short int grn_obj_flags;
 #define GRN_OBJ_WITH_SECTION           (0x01<<7)
 #define GRN_OBJ_WITH_WEIGHT            (0x01<<8)
 #define GRN_OBJ_WITH_POSITION          (0x01<<9)
-#define GRN_OBJ_WITH_BUFFER            (0x01<<10)
+#define GRN_OBJ_RING_BUFFER            (0x01<<10)
 
 #define GRN_OBJ_UNIT_MASK              (0x0f<<8)
 #define GRN_OBJ_UNIT_DOCUMENT_NONE     (0x00<<8)
@@ -2147,7 +2147,8 @@ GRN_API grn_rc grn_load(grn_ctx *ctx, grn_content_type input_type,
                         const char *table, unsigned table_len,
                         const char *columns, unsigned columns_len,
                         const char *values, unsigned values_len,
-                        const char *ifexists, unsigned ifexists_len);
+                        const char *ifexists, unsigned ifexists_len,
+                        const char *each, unsigned each_len);
 
 #define GRN_CTX_MORE                    (0x01<<0)
 #define GRN_CTX_TAIL                    (0x01<<1)
