@@ -19,15 +19,21 @@
 
 #include <stdio.h>
 #include <string.h>
-#ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
-#endif /* HAVE_SYS_SOCKET_H */
-#ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
-#endif /* HAVE_NETINET_IN_H */
-#ifdef HAVE_NETINET_TCP_H
-#include <netinet/tcp.h>
-#endif /* HAVE_NETINET_TCP_H */
+#include "ql.h"
+
+#ifdef WIN32
+#  include <ws2tcpip.h>
+#else
+#  ifdef HAVE_SYS_SOCKET_H
+#    include <sys/socket.h>
+#  endif /* HAVE_SYS_SOCKET_H */
+#  ifdef HAVE_NETINET_IN_H
+#    include <netinet/in.h>
+#  endif /* HAVE_NETINET_IN_H */
+#  ifdef HAVE_NETINET_TCP_H
+#   include <netinet/tcp.h>
+#  endif /* HAVE_NETINET_TCP_H */
+#endif /* WIN32 */
 
 #include "ctx.h"
 #include "com.h"
@@ -181,11 +187,11 @@ grn_msg_send(grn_ctx *ctx, grn_obj *msg, int flags)
       {
         if ((flags & GRN_CTX_MORE)) { flags |= GRN_CTX_QUIET; }
         if (ctx->stat == GRN_CTX_QUIT) { flags |= GRN_CTX_QUIT; }
-        header->qtype = 0;
+        header->qtype = (uint8_t) ctx->impl->output_type;
         header->keylen = 0;
         header->level = 0;
         header->flags = flags;
-        header->status = 0;
+        header->status = (uint16_t) ctx->rc;
         header->opaque = 0;
         header->cas = 0;
         //todo : MSG_DONTWAIT
@@ -384,7 +390,7 @@ grn_com_event_mod(grn_ctx *ctx, grn_com_event *ev, grn_sock fd, int events, grn_
       struct kevent e[2];
       EV_SET(&e[0], (fd), GRN_COM_POLLIN|GRN_COM_POLLOUT, EV_DELETE, 0, 0, NULL);
       EV_SET(&e[1], (fd), events, EV_ADD, 0, 0, NULL);
-      if (kevent(ev->kqfd, &e, 2, NULL, 0, NULL) == -1) {
+      if (kevent(ev->kqfd, e, 2, NULL, 0, NULL) == -1) {
         SERR("kevent");
         return ctx->rc;
       }
@@ -537,8 +543,11 @@ grn_com_event_poll(grn_ctx *ctx, grn_com_event *ev, int timeout)
 #endif /* USE_KQUEUE */
 #endif /* USE_EPOLL */
   if (nevents < 0) {
-    SERR("poll");
-    if (ctx->rc == GRN_INTERRUPTED_FUNCTION_CALL) { ERRCLR(ctx); }
+    if (ctx->rc == GRN_INTERRUPTED_FUNCTION_CALL) {
+      ERRCLR(ctx);
+    } else {
+      SERR("poll");
+    }
     return ctx->rc;
   }
   if (timeout < 0 && !nevents) { GRN_LOG(ctx, GRN_LOG_NOTICE, "poll returns 0 events"); }
@@ -907,9 +916,11 @@ grn_com_sopen(grn_ctx *ctx, grn_com_event *ev,
           "getaddrinfo: <%s:%s>: %s",
           listen_address, port_string, gai_strerror(getaddrinfo_result));
       break;
+#ifdef EAI_SYSTEM
     case EAI_SYSTEM:
       SERR("getaddrinfo");
       break;
+#endif
     default:
       ERR(GRN_INVALID_ARGUMENT,
           "getaddrinfo: <%s:%s>: %s",
