@@ -461,13 +461,21 @@ typedef struct {
 
 /**** cache ****/
 
+typedef struct {
+  uint32_t nentries;
+  uint32_t max_nentries;
+  uint32_t nfetches;
+  uint32_t nhits;
+} grn_cache_statistics;
+
 void grn_cache_init(void);
 grn_obj *grn_cache_fetch(grn_ctx *ctx, const char *str, uint32_t str_size);
 void grn_cache_unref(const char *str, uint32_t str_size);
 void grn_cache_update(grn_ctx *ctx, const char *str, uint32_t str_size, grn_obj *value);
 void grn_cache_expire(int32_t size);
 void grn_cache_fin(void);
-uint32_t *grn_cach_max_nentries(void);
+GRN_API uint32_t *grn_cache_max_nentries(void);
+void grn_cache_get_statistics(grn_ctx *ctx, grn_cache_statistics *statistics);
 
 /**** receive handler ****/
 
