@@ -40,6 +40,10 @@
 #include <sys/resource.h>
 #endif /* HAVE_SYS_RESOURCE_H */
 
+#ifdef HAVE_SYS_SYSCTL_H
+#include <sys/sysctl.h>
+#endif /* HAVE_SYS_SYSCTL_H */
+
 #ifndef USE_MSG_NOSIGNAL
 #define MSG_NOSIGNAL 0
 #endif /* USE_MSG_NOSIGNAL */
@@ -222,6 +226,19 @@ typedef enum {
   XML_PLACE_HIT
 } xml_place;
 
+static char *
+transform_xml_next_column(grn_obj *columns, int n)
+{
+  char *column = GRN_TEXT_VALUE(columns);
+  while (n--) {
+    while (*column) {
+      column++;
+    }
+    column++;
+  }
+  return column;
+}
+
 static void
 transform_xml(grn_ctx *ctx, grn_obj *output, grn_obj *transformed)
 {
@@ -232,7 +249,7 @@ transform_xml(grn_ctx *ctx, grn_obj *output, grn_obj *transformed)
   unsigned int len;
   int offset = 0, limit = 0, record_n = 0;
   int column_n, column_text_n, result_set_n = -1;
-  int in_vector = 0;
+  int in_vector = 0, first_vector_element = 0;
 
   s = GRN_TEXT_VALUE(output);
   e = GRN_BULK_CURR(output);
@@ -285,7 +302,12 @@ transform_xml(grn_ctx *ctx, grn_obj *output, grn_obj *transformed)
             GRN_TEXT_PUTS(ctx, transformed, "<NAVIGATIONENTRY>");
           }
         } else if (EQUAL_NAME_P("VECTOR")) {
+          char *c = transform_xml_next_column(&columns, column_n++);
           in_vector = 1;
+          first_vector_element = 1;
+          GRN_TEXT_PUTS(ctx, transformed, "<FIELD NAME=\"");
+          GRN_TEXT_PUTS(ctx, transformed, c);
+          GRN_TEXT_PUTS(ctx, transformed, "\">");
         }
         break;
       case XML_END_ELEMENT :
@@ -312,36 +334,35 @@ transform_xml(grn_ctx *ctx, grn_obj *output, grn_obj *transformed)
                         "</SEGMENTS>\n");
         } else if (EQUAL_NAME_P("VECTOR")) {
           in_vector = 0;
+          first_vector_element = 0;
+          GRN_TEXT_PUTS(ctx, transformed, "</FIELD>\n");
         } else {
           switch (place) {
           case XML_PLACE_HIT :
-            {
-              int i = column_n;
-              char *c = GRN_TEXT_VALUE(&columns);
-              while (i--) {
-                while (*c) {
-                  c++;
-                }
-                c++;
-              }
-              if (result_set_n == 0) {
+            if (result_set_n == 0) {
+              if (!in_vector) {
+                char *c = transform_xml_next_column(&columns, column_n++);
                 GRN_TEXT_PUTS(ctx, transformed, "<FIELD NAME=\"");
                 GRN_TEXT_PUTS(ctx, transformed, c);
                 GRN_TEXT_PUTS(ctx, transformed, "\">");
-                if (!in_vector) {
-                  GRN_TEXT_PUT(ctx, transformed,
-                               GRN_TEXT_VALUE(&buf), GRN_TEXT_LEN(&buf));
-                }
-                GRN_TEXT_PUTS(ctx, transformed, "</FIELD>\n");
-              } else {
-                GRN_TEXT_PUTS(ctx, transformed, c);
-                GRN_TEXT_PUTS(ctx, transformed, "=\"");
-                GRN_TEXT_PUT(ctx, transformed,
-                             GRN_TEXT_VALUE(&buf), GRN_TEXT_LEN(&buf));
-                GRN_TEXT_PUTS(ctx, transformed, "\" ");
               }
+              if (in_vector && !first_vector_element) {
+                GRN_TEXT_PUTS(ctx, transformed, ", ");
+              }
+              GRN_TEXT_PUT(ctx, transformed,
+                           GRN_TEXT_VALUE(&buf), GRN_TEXT_LEN(&buf));
+              if (!in_vector) {
+                GRN_TEXT_PUTS(ctx, transformed, "</FIELD>\n");
+              }
+            } else {
+              char *c = transform_xml_next_column(&columns, column_n++);
+              GRN_TEXT_PUTS(ctx, transformed, c);
+              GRN_TEXT_PUTS(ctx, transformed, "=\"");
+              GRN_TEXT_PUT(ctx, transformed,
+                           GRN_TEXT_VALUE(&buf), GRN_TEXT_LEN(&buf));
+              GRN_TEXT_PUTS(ctx, transformed, "\" ");
             }
-            column_n++;
+            first_vector_element = 0;
             break;
           default :
             if (EQUAL_NAME_P("NHITS")) {
@@ -1909,7 +1930,7 @@ enum {
   grn_logger_info_set(&grn_gctx, &info);\
 } while(0)
 
-uint32_t
+static uint32_t
 get_core_number(void)
 {
 #ifdef WIN32
@@ -1917,7 +1938,21 @@ get_core_number(void)
   GetSystemInfo(&sinfo);
   return sinfo.dwNumberOfProcessors;
 #else /* WIN32 */
+#  ifdef _SC_NPROCESSORS_CONF
   return sysconf(_SC_NPROCESSORS_CONF);
+#  else
+  int n_processors;
+  size_t length = sizeof(n_processors);
+  int mib[] = {CTL_HW, HW_NCPU};
+  if (sysctl(mib, sizeof(mib) / sizeof(mib[0]),
+             &n_processors, &length, NULL, 0) == 0 &&
+      length == sizeof(n_processors) &&
+      0 < n_processors) {
+    return n_processors;
+  } else {
+    return 1;
+  }
+#  endif /* _SC_NPROCESSORS_CONF */
 #endif /* WIN32 */
 }
 
