@@ -66,6 +66,8 @@ void test_column_var_size(void);
 void test_column_index(void);
 void test_type(void);
 void test_record(void);
+void test_proc_command(void);
+void test_proc_function(void);
 
 static gchar *tmp_directory;
 
@@ -349,7 +351,11 @@ test_geo_point_tokyo(void)
   geo_point_tokyo = grn_obj_open(context, GRN_BULK, 0, GRN_DB_TOKYO_GEO_POINT);
   GRN_GEO_POINT_SET(context, geo_point_tokyo, takane_latitude, takane_longitude);
   inspected = grn_inspect(context, NULL, geo_point_tokyo);
-  cut_assert_equal_string("\"130194581x503802073\"", inspected_string());
+  cut_assert_equal_string("[(130194581,503802073) "
+                          "((36, 9, 54, 581),(139, 56, 42, 73)) "
+                          "[00000001 01111110 10100000 00011101 "
+                          "10010110 11100000 11010011 01100011]]",
+                          inspected_string());
 }
 
 void
@@ -363,7 +369,11 @@ test_geo_point_wgs84(void)
   geo_point_wgs84 = grn_obj_open(context, GRN_BULK, 0, GRN_DB_WGS84_GEO_POINT);
   GRN_GEO_POINT_SET(context, geo_point_wgs84, takane_latitude, takane_longitude);
   inspected = grn_inspect(context, NULL, geo_point_wgs84);
-  cut_assert_equal_string("\"130226900x503769900\"", inspected_string());
+  cut_assert_equal_string("[(130226900,503769900) "
+                          "((36, 10, 26, 900),(139, 56, 9, 900)) "
+                          "[00000001 01111110 10100000 00011110 "
+                          "01010110 11001101 10100110 01110000]]",
+                          inspected_string());
 }
 
 void
@@ -798,3 +808,31 @@ test_record(void)
                           ">",
                           inspected_string());
 }
+
+void
+test_proc_command(void)
+{
+  grn_obj *proc;
+
+  proc = get_object("column_remove");
+  inspected = grn_inspect(context, NULL, proc);
+  cut_assert_equal_string("#<proc:command "
+                          "column_remove "
+                          "arguments:[table, name]"
+                          ">",
+                          inspected_string());
+}
+
+void
+test_proc_function(void)
+{
+  grn_obj *proc;
+
+  proc = get_object("geo_distance");
+  inspected = grn_inspect(context, NULL, proc);
+  cut_assert_equal_string("#<proc:function "
+                          "geo_distance "
+                          "arguments:[]"
+                          ">",
+                          inspected_string());
+}
